.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Table of Contents

   readme
   _generated/api/modules
   contributing

.. include:: readme.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
